%define Werror_cflags %nil
%define _disable_ld_no_undefined 1

%define major    0
%define libdf    %mklibname df %{major}
%define libmfhdf %mklibname mfhdf %{major}

%bcond_without java

Name:           hdf
Version:        4.3.0
Release:        %mkrel 1
Summary:        A general purpose library and file format for storing scientific data
License:        BSD
Group:          System/Libraries
URL:            https://portal.hdfgroup.org/
Source0:        https://github.com/HDFGroup/hdf4/archive/hdf%{version}.tar.gz
Source1:        h4comp
# Fix java build
Patch1:         hdf-build.patch
BuildRequires:  flex
BuildRequires:  byacc
BuildRequires:  chrpath
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libtirpc)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  libaec-devel
BuildRequires:  gcc-gfortran
%if %{with java}
BuildRequires:  java-devel
BuildRequires:  javapackages-tools
BuildRequires:  hamcrest
BuildRequires:  junit
BuildRequires:  slf4j
%else
Obsoletes:      java-hdf < %{version}-%{release}
%endif
Obsoletes:      HDF-util < %{version}-%{release}


%description
HDF is a general purpose library and file format for storing scientific data.
HDF can store two primary objects: datasets and groups. A dataset is
essentially a multidimensional array of data elements, and a group is a
structure for organizing objects in an HDF file. Using these two basic
objects, one can create and store almost any kind of scientific data
structure, such as images, arrays of vectors, and structured and unstructured
grids. You can also mix and match them in HDF files according to your needs.


%package devel
Summary:        HDF development files
Group:          Development/C
Requires:       %{name} = %{version}-%{release}
Requires:       %{libdf} = %{version}-%{release}
Requires:       %{libmfhdf} = %{version}-%{release}
Requires:       pkgconfig(libjpeg)
Requires:       pkgconfig(libtirpc)
Requires:       pkgconfig(zlib)
Obsoletes:      HDF < %{version}-%{release}

%description devel
HDF development headers and libraries.


%package -n %{libdf}
Summary:        HDF4 shared libraries
Group:          System/Libraries

%description -n %{libdf}
HDF4 shared libraries.


%package -n %{libmfhdf}
Summary:        HDF4 shared libraries
Group:          System/Libraries

%description -n %{libmfhdf}
HDF4 shared libraries.


%package static
Summary:        HDF4 static libraries
Group:          Development/C
Requires:       %{name}-devel = %{version}-%{release}

%description static
HDF4 static libraries.


%if %{with java}
%package -n java-hdf
Summary:        HDF4 java library
Group:          Development/Java
Requires:       slf4j

%description -n java-hdf
HDF4 java library.
%endif


%prep
%setup -q -n hdf4-hdf%{version}
%patch -P 1 -p1 -b .build

%if %{with java}
# Replace jars with system versions
# hamcrest-core is obsoleted in hamcrest-2.2
# Junit tests are failing with junit-4.13.1
find . ! -name junit.jar -name "*.jar" -delete
ln -s $(build-classpath hamcrest) java/lib/hamcrest-core.jar

ln -s $(build-classpath slf4j/api) java/lib/slf4j-api-1.7.33.jar
ln -s $(build-classpath slf4j/nop) java/lib/ext/slf4j-nop-1.7.33.jar
ln -s $(build-classpath slf4j/simple) java/lib/ext/slf4j-simple-1.7.33.jar
%endif

find . -type f -name "*.h" -exec chmod 0644 '{}' \;
find . -type f -name "*.c" -exec chmod 0644 '{}' \;

# restore include file timestamps modified by patching
#touch -c -r ./hdf/src/hdfi.h.ppc ./hdf/src/hdfi.h

%build

# For destdir/examplesdir patches
autoreconf -vfi

# avoid upstream compiler flags settings
rm config/*linux-gnu

# TODO: upstream fix
# libmfhdf.so is link to libdf.so
export CFLAGS="%{optflags} -std=gnu17 -I%{_usr}/include/tirpc"
export LIBS="-ltirpc"
%global _configure ../configure
# Java test needs this but doesn't create it
mkdir -p build-shared/java/lib
cd build-shared
# Java requires shared libraries, fortran requires static
%configure --disable-production %{?with_java:--enable-java} --disable-netcdf \
 --enable-shared=yes --enable-static=no --disable-fortran --with-szlib \
 --includedir=%{_includedir}/%{name}
%make_build
cd -
mkdir build-static
cd build-static
# Java requires shared libraries, fortran requires static

# Temporary workaround for compiling on GCC-10
export FCFLAGS="%{build_fflags} -fallow-argument-mismatch"
export FFLAGS="%{build_fflags} -fallow-argument-mismatch"

%configure --disable-production --disable-java --disable-netcdf \
 --enable-shared=no --enable-static=yes --enable-fortran --with-szlib \
 --includedir=%{_includedir}/%{name}
%make_build
cd -

# correct the timestamps based on files used to generate the header files
touch -c -r hdf/src/hdf.inc hdf/src/hdf.f90
touch -c -r hdf/src/dffunc.inc hdf/src/dffunc.f90
touch -c -r mfhdf/fortran/mffunc.inc mfhdf/fortran/mffunc.f90
# netcdf fortran include need same treatement, but they are not shipped


%install
%make_install -C build-static
%make_install -C build-shared
chrpath --delete --keepgoing %{buildroot}%{_bindir}/* %{buildroot}%{_libdir}/%{name}/*.so.* \
	%{buildroot}%{_libdir}/*.so.* || :

#Don't conflict with netcdf
for file in ncdump ncgen; do
  mv %{buildroot}%{_bindir}/$file %{buildroot}%{_bindir}/h$file
  # man pages are the same than netcdf ones
  rm %{buildroot}%{_mandir}/man1/${file}.1
done

#Fixup headers and scripts for multiarch
%if "%{_lib}" == "lib64"
for x in h4cc h4fc
do
  mv %{buildroot}%{_bindir}/${x} \
     %{buildroot}%{_bindir}/${x}-64
  install -m 0755 %SOURCE1 %{buildroot}%{_bindir}/${x}
done
%else
for x in h4cc h4fc
do
  mv %{buildroot}%{_bindir}/${x} \
     %{buildroot}%{_bindir}/${x}-32
  install -m 0755 %SOURCE1 %{buildroot}%{_bindir}/${x}
done
%endif


%check
make -j1 -C build-shared check
make -j1 -C build-static check


%files
%license COPYING
%doc README.md release_notes/*.txt
%{_bindir}/*

%files devel
%{_includedir}/%{name}/
%{_libdir}/*.so
%{_libdir}/*.settings

%files -n %{libdf}
%{_libdir}/libdf.so.%{major}{,.*}

%files -n %{libmfhdf}
%{_libdir}/libmfhdf.so.%{major}{,.*}

%files static
%{_libdir}/*.a

%if %{with java}
%files -n java-hdf
%{_jnidir}/hdf.jar
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/libhdf_java.so
%endif


%changelog
* Sun Feb 23 2025 daviddavid <daviddavid> 4.3.0-1.mga10
+ Revision: 2150980
- new version: 4.3.0
+ pterjan <pterjan>
- Rebuild for patchN deprecation

* Sat Oct 29 2022 ghibo <ghibo> 4.2.15-8.mga9
+ Revision: 1899973
- Fix chrpath for building.
- Add further patches from opensuse.
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Tue Jan 05 2021 daviddavid <daviddavid> 4.2.15-7.mga8
+ Revision: 1669054
- enable now the shared libs
- enable the java bindings

* Mon Jan 04 2021 daviddavid <daviddavid> 4.2.15-6.mga8
+ Revision: 1668838
- link mfhdf to -ltirpc

* Mon Jan 04 2021 daviddavid <daviddavid> 4.2.15-5.mga8
+ Revision: 1668804
- devel sub-pkg require also libtirpc-devel

* Thu Nov 26 2020 tv <tv> 4.2.15-4.mga8
+ Revision: 1649455
- Use LIBS instead of LDFLAGS for -ltirpc (fix build with glibc-2.32)

* Tue Oct 13 2020 daviddavid <daviddavid> 4.2.15-3.mga8
+ Revision: 1635125
- move libraries into %%{_libdir}

* Mon Jun 29 2020 joequant <joequant> 4.2.15-2.mga8
+ Revision: 1600383
- fix to gcc10

* Fri May 01 2020 daviddavid <daviddavid> 4.2.15-1.mga8
+ Revision: 1577354
- new version: 4.2.15

* Sat Feb 15 2020 umeabot <umeabot> 4.2.14-2.mga8
+ Revision: 1523949
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sat Mar 16 2019 daviddavid <daviddavid> 4.2.14-1.mga7
+ Revision: 1378029
- new version: 4.2.14

* Sun Sep 23 2018 umeabot <umeabot> 4.2.13-2.mga7
+ Revision: 1298174
- Mageia 7 Mass Rebuild

* Thu Jun 21 2018 wally <wally> 4.2.13-1.mga7
+ Revision: 1238543
- new version 4.2.13
- sync patches and partially .spec from Fedora

* Mon Feb 08 2016 umeabot <umeabot> 4.2.9-6.mga6
+ Revision: 947169
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 4.2.9-5.mga5
+ Revision: 742154
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 4.2.9-4.mga5
+ Revision: 680097
- Mageia 5 Mass Rebuild

* Sun Jul 20 2014 grenoya <grenoya> 4.2.9-3.mga5
+ Revision: 654806
- add obsoletes on HDF and HDF-util

* Sat Oct 19 2013 umeabot <umeabot> 4.2.9-2.mga4
+ Revision: 530080
- Mageia 4 Mass Rebuild

* Tue Jul 16 2013 fwang <fwang> 4.2.9-1.mga4
+ Revision: 454991
- cleanup spec
- new version 4.2.9

* Sat Jan 12 2013 umeabot <umeabot> 4.2.8-3.mga3
+ Revision: 353144
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Jan 09 2013 dmorgan <dmorgan> 4.2.8-2.mga3
+ Revision: 343362
- imported package hdf


* Fri Dec 21 2012 Adam Tkac <atkac redhat com> - 4.2.8-2
- rebuild against new libjpeg

* Wed Aug 15 2012 Orion Poplawski <orion@cora.nwra.com> 4.2.8-1
- Update to 4.2.8

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.2.7-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Tue Mar 06 2012 DJ Delorie <dj@redhat.com> 4.2.7-2
- Add patch for ARM support

* Wed Feb 15 2012 Orion Poplawski <orion@cora.nwra.com> 4.2.7-1
- Update to 4.2.7

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.2.6-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Tue Jun 21 2011 Orion Poplawski <orion@cora.nwra.com> 4.2.6-1
- Update to 4.2.6
- Drop jpeg patch, fixed upstream
- Update ppc,s390 patches

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.2.5-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Fri Dec 10 2010 Orion Poplawski <orion@cora.nwra.com> 4.2.5-2
- Add patch to disable jpeg tests due to change to jpeg-turbo, FTBFS bug 631337

* Tue Mar 2 2010 Orion Poplawski <orion@cora.nwra.com> 4.2.5-1
- Update to 4.2.5

* Fri Sep 18 2009 Orion Poplawski <orion@cora.nwra.com> 4.2r4-5
- Add EL4 build conditionals

* Thu Aug 13 2009 Orion Poplawski <orion@cora.nwra.com> 4.2r4-4
- Add -fPIC to FFLAGS

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.2r4-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Tue Apr 7 2009 Orion Poplawski <orion@cora.nwra.com> 4.2r4-2
- Add Provides hdf-static to hdf-devel (bug #494529)

* Wed Feb 25 2009 Orion Poplawski <orion@cora.nwra.com> 4.2r4-1
- Update to 4.2r4
- Add patch to increase buffer size in test
- Drop upstreamed libm patch

* Tue Feb 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.2r3-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Wed Oct  1 2008 Orion Poplawski <orion@cora.nwra.com> 4.2r3-4
- Rebase maxavailfiles patch

* Sun Sep 21 2008 Ville Skyttä <ville.skytta at iki.fi> - 4.2r3-3
- Fix Patch0:/%%patch mismatch.

* Sun Mar  2 2008 Patrice Dumas <pertusus@free.fr> 4.2r3-2
- don't ship an empty netcdf.h file. The related definitions are now
  in hdf4_netcdf.h

* Tue Feb  5 2008 Orion Poplawski <orion@cora.nwra.com> 4.2.r3-1
- Update to 4.2r3

* Tue Feb  5 2008 Orion Poplawski <orion@cora.nwra.com> 4.2.r2-7
- Add patch to add -lm to hdiff link

* Tue Feb  5 2008 Orion Poplawski <orion@cora.nwra.com> 4.2.r2-6
- Add patch for s390 support (bug #431511)

* Mon Jan  7 2008 Orion Poplawski <orion@cora.nwra.com> 4.2.r2-5
- Add patches for sparc support (bug #427639)

* Mon Oct 29 2007 Patrice Dumas <pertusus@free.fr> 4.2r2-4
- install the netcdf.h file that describes the netcdf2 hdf enabled
  API

* Mon Oct 29 2007 Patrice Dumas <pertusus@free.fr> 4.2r2-3
- ship hdf enabled nc* utils as hnc*
- add --disable-netcdf that replaces HAVE_NETCDF
- keep include files timestamps, and have the same accross arches
- fix multiarch difference in include files (#341491)

* Wed Oct 17 2007 Patrice Dumas <pertusus@free.fr> 4.2r2-2
- update to 4.2r2

* Fri Aug 24 2007 Orion Poplawski <orion@cora.nwra.com> 4.2r1-15
- Update license tag to BSD
- Rebuild for BuildID

* Thu May 10 2007 Balint Cristian <cbalint@redhat.com> 4.2r1-14
- Fix ppc64 too.

* Thu May 10 2007 Orion Poplawski <orion@cora.nwra.com> 4.2r1-13
- Remove netcdf-devel requires. (bug #239631)

* Fri Apr 20 2007 Orion Poplawski <orion@cora.nwra.com> 4.2r1-12
- Use 4.2r1-hrepack-p4.tar.gz for hrepack patch
- Remove configure patch applied upstream
- Use --disable-production configure flag to avoid stripping -g compile flag
- Add patch to fix open file test when run under mock

* Tue Aug 29 2006 Orion Poplawski <orion@cora.nwra.com> 4.2r1-11
- Rebuild for FC6

* Thu Apr 20 2006 Orion Poplawski <orion@cora.nwra.com> 4.2r1-10
- Add Requires netcdf-devel for hdf-devel (bug #189337)

* Mon Feb 13 2006 Orion Poplawski <orion@cora.nwra.com> 4.2r1-9
- Rebuild for gcc/glibc changes

* Wed Feb  8 2006 Orion Poplawski <orion@cora.nwra.com> 4.2r1-8
- Compile with -DHAVE_NETCDF for gdl hdf/netcdf compatibility

* Thu Feb  2 2006 Orion Poplawski <orion@cora.nwra.com> 4.2r1-7
- Add patch to build on ppc

* Wed Dec 21 2005 Orion Poplawski <orion@cora.nwra.com> 4.2r1-6
- Rebuild

* Wed Oct 05 2005 Orion Poplawski <orion@cora.nwra.com> 4.2r1-5
- Add Requires: libjpeg-devel zlib-devel to -devel package

* Tue Aug 23 2005 Orion Poplawski <orion@cora.nwra.com> 4.2r1-4
- Use -fPIC
- Fix project URL

* Fri Jul 29 2005 Orion Poplawski <orion@cora.nwra.com> 4.2r1-3
- Exclude ppc/ppc64 - HDF does not recognize it

* Wed Jul 20 2005 Orion Poplawski <orion@cora.nwra.com> 4.2r1-2
- Fix BuildRequires to have autoconf

* Fri Jul 15 2005 Orion Poplawski <orion@cora.nwra.com> 4.2r1-1
- inital package for Fedora Extras
